package corel.webdata;

import java.awt.Canvas;
import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Insets;
import java.awt.Rectangle;
import java.util.Hashtable;
import java.util.StringTokenizer;
import java.util.Vector;

public class ChartGeneric extends Canvas {
   protected boolean isStacked;
   protected boolean gridYes;
   protected ChartLegend legend;
   protected boolean showValues;
   protected boolean hasShadow;
   protected String bkImageURL;
   protected Vector data;
   protected String dataStr;
   protected Vector columnTitles;
   protected Vector rowTitles;
   protected float biggestElement;
   protected float smallestElement;
   protected AxisLook numaxisLook;
   protected AxisLook ordaxisLook;
   protected static final int TICKWIDTH = 5;
   protected Insets chartInsets;
   protected Insets textInsets;
   protected static final int ALIGNLEFT = 0;
   protected static final int ALIGNCENTER = 1;
   protected static final int ALIGNRIGHT = 2;
   protected Font defaultFont;
   protected static final String DEFAULTFONTNAME = "Arial";
   protected int xdivSize;
   protected int ydivSize;
   protected Rectangle axisFrame;
   protected int numDataSets;
   protected int numCategories;
   protected Color bkColor;
   protected boolean rowRange;
   protected boolean columnRange;
   protected Vector rangeElements;
   protected Hashtable attributes;
   int axisOriginX;
   int axisOriginY;
   int divSize1;
   int divSize2;
   int axisFrameRight;
   int maxLabelWidth;
   boolean drawLabelOnDiffLevels;
   boolean drawVertLabelOnDiffLevels;
   int overlapFactor;
   int overlapFactorVert;

   public ChartGeneric() {
      this.chartInsets = new Insets(8, 8, 8, 8);
      this.textInsets = new Insets(3, 3, 3, 3);
      this.bkColor = Color.white;
      this.rowRange = false;
      this.columnRange = false;
      this.rangeElements = new Vector();
      this.drawLabelOnDiffLevels = false;
      this.drawVertLabelOnDiffLevels = false;
      this.data = new Vector();
      this.columnTitles = new Vector();
      this.rowTitles = new Vector();
      this.numaxisLook = new AxisLook();
      this.ordaxisLook = new AxisLook();
      this.defaultFont = new Font("Arial", 0, 10);
      this.attributes = new Hashtable();
   }

   public ChartGeneric(boolean var1, ChartLegend var2, boolean var3, String var4, boolean var5) {
      this();
      this.gridYes = var1;
      this.legend = var2;
      this.showValues = var3;
      this.bkImageURL = var4;
      this.hasShadow = var5;
      this.legend.setChart(this);
      this.attributes.put(HARes.HC_ATTR_GRID, new Boolean(this.gridYes));
      this.attributes.put(HARes.HC_ATTR_SHADOW, new Boolean(this.hasShadow));
      this.attributes.put(HARes.HC_ATTR_STACKED, new Boolean(this.isStacked));
      this.attributes.put(HARes.HC_ATTR_VALUES, new Boolean(this.showValues));
      this.attributes.put(HARes.HC_ATTR_BACKGROUND, this.bkColor);
   }

   public ChartGeneric(boolean var1, ChartLegend var2, boolean var3, String var4, boolean var5, Color var6) {
      this(var1, var2, var3, var4, var5);
      this.bkColor = var6;
      this.attributes.put(HARes.HC_ATTR_BACKGROUND, this.bkColor);
   }

   public synchronized void reshape(int var1, int var2, int var3, int var4) {
      super.reshape(var1, var2, var3, var4);
      this.recalculate(var3, var4);
   }

   protected void recalculate(int var1, int var2) {
      FontMetrics var3 = ((Component)this).getGraphics().getFontMetrics();
      this.axisOriginX = this.getAxisOriginX(var3);
      this.axisOriginY = this.getAxisOriginY(var3);
      if (this.axisOriginY == var2) {
         --this.axisOriginY;
      }

      this.divSize1 = (int)Math.ceil((double)((float)(this.axisOriginY - this.chartInsets.top) / (float)((this.isVertical() ? this.numaxisLook : this.ordaxisLook).labels.length - (this.isVertical() ? 1 : 0))));
      this.divSize2 = (int)Math.ceil((double)((float)(var1 - this.chartInsets.right - this.axisOriginX) / (float)((this.isVertical() ? this.ordaxisLook : this.numaxisLook).labels.length - (this.isVertical() ? 0 : 1))));
      this.axisFrameRight = var1 - this.chartInsets.right;
      this.maxLabelWidth = this.getMaxLabelAxisWidth(var3, this.isVertical() ? this.ordaxisLook : this.numaxisLook);
      this.drawLabelOnDiffLevels = this.maxLabelWidth > this.divSize2;
      this.drawVertLabelOnDiffLevels = var3.getHeight() > this.divSize1;
      if (this.drawLabelOnDiffLevels) {
         this.axisOriginY -= var3.getHeight() - var3.getLeading();
      }

      this.overlapFactor = (int)Math.ceil((double)((float)this.maxLabelWidth / (float)this.divSize2));
      this.overlapFactorVert = (int)Math.ceil((double)((float)var3.getHeight() / (float)this.divSize1));
      if (this.overlapFactor == 2 && this.isVertical()) {
         --this.overlapFactor;
      }

      this.axisFrame = new Rectangle();
      this.axisFrame.x = this.axisOriginX;
      this.axisFrame.y = this.chartInsets.top;
      this.axisFrame.width = this.axisFrameRight - this.axisFrame.x;
      this.axisFrame.height = this.axisOriginY - this.axisFrame.y;
      this.numaxisLook.pt1.x = this.axisOriginX;
      this.numaxisLook.pt1.y = this.isVertical() ? this.chartInsets.top : this.axisOriginY;
      this.numaxisLook.pt2.x = this.isVertical() ? this.axisOriginX : this.axisFrameRight;
      this.numaxisLook.pt2.y = this.axisOriginY;
      this.numaxisLook.isVertical = this.isVertical();
      this.numaxisLook.screenDivSize = this.numaxisLook.isVertical ? this.divSize1 : this.divSize2;
      this.numaxisLook.isNumeric = true;
      this.ordaxisLook.pt1.x = this.axisOriginX;
      this.ordaxisLook.pt1.y = this.isVertical() ? this.axisOriginY : this.chartInsets.top;
      this.ordaxisLook.pt2.x = this.isVertical() ? this.axisFrameRight : this.axisOriginX;
      this.ordaxisLook.pt2.y = this.axisOriginY;
      this.ordaxisLook.isVertical = !this.isVertical();
      this.ordaxisLook.screenDivSize = this.ordaxisLook.isVertical ? this.divSize1 : this.divSize2;
      this.ordaxisLook.isNumeric = false;
      int var4 = this.numaxisLook.labels.length;
      this.numaxisLook.divisions = new int[var4];

      for(int var5 = 0; var5 < var4; ++var5) {
         if (this.numaxisLook.isVertical) {
            this.numaxisLook.divisions[var5] = this.axisFrame.height * var5 / (var4 - 1);
         } else {
            this.numaxisLook.divisions[var5] = this.axisFrame.width * var5 / (var4 - 1);
         }
      }

      var4 = this.ordaxisLook.labels.length + 1;
      this.ordaxisLook.divisions = new int[var4];

      for(int var6 = 0; var6 < var4; ++var6) {
         if (this.ordaxisLook.isVertical) {
            this.ordaxisLook.divisions[var6] = this.axisFrame.height * var6 / (var4 - 1);
         } else {
            this.ordaxisLook.divisions[var6] = this.axisFrame.width * var6 / (var4 - 1);
         }
      }

      for(int var7 = 0; var7 < this.numaxisLook.labels.length; ++var7) {
         try {
            if (new Integer(this.numaxisLook.labels[var7]) == 0) {
               if (this.isVertical()) {
                  this.ordaxisLook.pt1.y = this.numaxisLook.pt2.y - this.numaxisLook.divisions[var7];
                  this.ordaxisLook.pt2.y = this.numaxisLook.pt2.y - this.numaxisLook.divisions[var7];
                  return;
               }

               this.ordaxisLook.pt1.x = this.numaxisLook.pt1.x + this.numaxisLook.divisions[var7];
               this.ordaxisLook.pt2.x = this.numaxisLook.pt1.x + this.numaxisLook.divisions[var7];
               return;
            }
         } catch (Exception var9) {
            ((Throwable)var9).printStackTrace();
         }
      }

   }

   public void paint(Graphics var1) {
      ((Component)this).size();
      var1.setFont(this.defaultFont);
      FontMetrics var2 = var1.getFontMetrics();
      this.numaxisLook.isGrid = this.isGrid();
      this.ordaxisLook.isGrid = this.isGrid();
      var1.setColor(Color.gray);
      var1.drawRect(this.axisFrame.x, this.axisFrame.y, this.axisFrame.width, this.axisFrame.height);
      var1.setColor(this.bkColor);
      var1.fillRect(this.axisFrame.x + 1, this.axisFrame.y + 1, this.axisFrame.width - 1, this.axisFrame.height - 1);
      var1.setColor(Color.black);
      AxisLook[] var3 = new AxisLook[]{this.numaxisLook, this.ordaxisLook};

      for(int var4 = 0; this.axisAreVisible() && var4 < var3.length; ++var4) {
         var1.drawLine(var3[var4].pt1.x, var3[var4].pt1.y, var3[var4].pt2.x, var3[var4].pt2.y);

         try {
            for(int var5 = 0; var5 < var3[var4].divisions.length; ++var5) {
               if (var3[var4].isVertical) {
                  var1.drawLine(var3[var4].pt1.x - 2, var3[var4].pt2.y - var3[var4].divisions[var5], var3[var4].pt1.x + 2, var3[var4].pt2.y - var3[var4].divisions[var5]);
               } else {
                  var1.drawLine(var3[var4].pt1.x - -var3[var4].divisions[var5], var3[var4].pt2.y - 2, var3[var4].pt1.x + var3[var4].divisions[var5], var3[var4].pt2.y - -2);
               }

               if (var3[var4].isGrid && var5 != 0) {
                  if (var3[var4].isNumeric && var5 < var3[var4].labels.length - 1) {
                     if (var3[var4].isVertical) {
                        var1.drawLine(var3[var4].pt1.x, var3[var4].pt2.y - var3[var4].divisions[var5], this.axisFrame.x + this.axisFrame.width, var3[var4].pt2.y - var3[var4].divisions[var5]);
                     } else {
                        var1.drawLine(var3[var4].pt1.x + var3[var4].divisions[var5], var3[var4].pt1.y, var3[var4].pt1.x + var3[var4].divisions[var5], this.axisFrame.y);
                     }
                  }

                  if (!var3[var4].isNumeric) {
                     if (var3[var4].isVertical) {
                        var1.drawLine(this.axisFrame.x, var3[var4].pt2.y - var3[var4].divisions[var5], this.axisFrame.x + this.axisFrame.width, var3[var4].pt2.y - var3[var4].divisions[var5]);
                     } else {
                        var1.drawLine(var3[var4].pt1.x + var3[var4].divisions[var5], this.axisFrame.y + this.axisFrame.height, var3[var4].pt1.x + var3[var4].divisions[var5], this.axisFrame.y);
                     }
                  }
               }
            }
         } catch (Exception var11) {
            ((Throwable)var11).printStackTrace();
         }
      }

      this.paintData(var1);
      var1.setColor(Color.black);

      for(int var12 = 0; this.axisAreVisible() && var12 < var3.length; ++var12) {
         try {
            for(int var6 = 0; var6 < var3[var12].labels.length; ++var6) {
               if (var3[var12].isVertical) {
                  if (!this.drawVertLabelOnDiffLevels || var6 % (this.overlapFactorVert * 2) == 0) {
                     this.drawStringByLine(var1, this.chartInsets.left, (int)((double)(var3[var12].pt2.y - var3[var12].divisions[var6]) - (var3[var12].isNumeric ? (double)0.0F : (double)0.5F * (double)(var3[var12].divisions[var6 + 1] - var3[var12].divisions[var6]))), var3[var12].isNumeric ? var3[var12].pt2.x - this.chartInsets.left : this.axisFrame.x - this.textInsets.right, var3[var12].labels[var6], 2);
                  }
               } else if (!this.drawLabelOnDiffLevels || var6 % this.overlapFactor == 0) {
                  boolean var7;
                  if (var6 >= var3[var12].labels.length - 1 && var6 != 0) {
                     var7 = var2.stringWidth(var3[var12].labels[var6]) + this.textInsets.left + this.textInsets.right > var3[var12].divisions[var6] - var3[var12].divisions[var6 - 1];
                  } else {
                     var7 = var2.stringWidth(var3[var12].labels[var6]) + this.textInsets.left + this.textInsets.right > var3[var12].divisions[var6 + 1] - var3[var12].divisions[var6];
                  }

                  byte var8 = 1;
                  if (var7) {
                     if (var6 == 0) {
                        var8 = 0;
                     }

                     if (var6 == var3[var12].labels.length - 1) {
                        var8 = 2;
                     }
                  }

                  int var9 = (int)((double)(var3[var12].pt1.x + var3[var12].divisions[var6]) + (var3[var12].isNumeric ? (double)0.0F : (double)0.5F * (double)(var3[var12].divisions[var6 + 1] - var3[var12].divisions[var6])));
                  if (var8 == 0) {
                     var9 = this.axisFrame.x - this.textInsets.left;
                  }

                  if (var8 == 2) {
                     var9 = this.axisFrame.x + this.axisFrame.width + this.textInsets.right;
                  }

                  if (this.drawLabelOnDiffLevels && var6 % (this.overlapFactor * 2) != 0) {
                     this.drawStringByLine(var1, var9, (var3[var12].isNumeric ? var3[var12].pt2.y : this.axisFrame.y + this.axisFrame.height) + 2 + this.textInsets.top + (var2.getHeight() - var2.getLeading()) / 2 + var2.getHeight(), 0, var3[var12].labels[var6], var8);
                  } else {
                     this.drawStringByLine(var1, var9, (var3[var12].isNumeric ? var3[var12].pt2.y : this.axisFrame.y + this.axisFrame.height) + 2 + this.textInsets.top + (var2.getHeight() - var2.getLeading()) / 2, 0, var3[var12].labels[var6], var8);
                  }
               }
            }
         } catch (Exception var10) {
            ((Throwable)var10).printStackTrace();
         }
      }

   }

   protected void paintData(Graphics var1) {
   }

   public void paintLegendBox(int var1, Graphics var2, Rectangle var3, Color var4) {
      GraphExt.draw3dRectEx(var2, var3.x, var3.y, var3.width, var3.height, 2);
      var2.setColor(var4);
      var2.fillRect(var3.x + 2, var3.y + 2, var3.width - 4, var3.height - 4);
   }

   protected int getAxisOriginX(FontMetrics var1) {
      if (!this.axisAreVisible()) {
         return 0;
      } else {
         int var2 = this.getMaxLabelAxisWidth(var1, this.isVertical() ? this.numaxisLook : this.ordaxisLook);
         var2 += 2;
         var2 += this.chartInsets.left;
         return var2;
      }
   }

   protected int getAxisOriginY(FontMetrics var1) {
      if (!this.axisAreVisible()) {
         return ((Component)this).size().height;
      } else {
         int var2 = var1.getHeight() - var1.getLeading();
         var2 += 2;
         var2 += this.chartInsets.bottom + this.textInsets.top + this.textInsets.bottom;
         return ((Component)this).size().height - var2;
      }
   }

   protected int getMaxLabelAxisWidth(FontMetrics var1, AxisLook var2) {
      int var3 = 0;

      for(int var4 = 0; var4 < var2.labels.length; ++var4) {
         var3 = Math.max(var3, var1.stringWidth(var2.labels[var4]));
      }

      return var3 + this.textInsets.left + this.textInsets.right;
   }

   protected void drawStringByLine(Graphics var1, int var2, int var3, int var4, String var5, int var6) {
      FontMetrics var7 = var1.getFontMetrics();
      int var8 = var7.stringWidth(var5);
      if (var4 > 0) {
         var4 -= this.textInsets.left + this.textInsets.right;
      }

      int var9 = var2;
      switch (var6) {
         case 0:
            var9 = var2 + this.textInsets.left;
            break;
         case 1:
            var9 = var2 + (var4 - var8) / 2;
            break;
         case 2:
            var9 = var2 + (var4 - var8);
      }

      int var10 = var3 + var7.getAscent() / 2;
      var1.drawString(var5, var9, var10);
   }

   public void setData(String var1) {
      this.setData(var1, false, false, (Vector)null);
   }

   public void setData(String var1, boolean var2, boolean var3, Vector var4) {
      this.dataStr = var1;
      ViewTokenizer var5 = new ViewTokenizer(var1, HARes.HA_RECORDDELIM);
      this.data.removeAllElements();
      this.columnTitles.removeAllElements();
      this.rowTitles.removeAllElements();
      this.numaxisLook = new AxisLook();
      this.ordaxisLook = new AxisLook();

      for(int var6 = 0; var5.hasMoreTokens(); ++var6) {
         String var7 = var5.getNextToken();
         if (var7.trim().length() != 0) {
            ViewTokenizer var8 = new ViewTokenizer(var7, HARes.HA_FIELDDELIM);
            Vector var9 = new Vector();
            if (var6 <= 0 || !var2 || this.checkInRange(var6, var4)) {
               for(int var10 = 0; var8.hasMoreTokens(); ++var10) {
                  String var11 = var8.getNextToken().trim();
                  String[] var12 = this.checkForTags(var11);
                  var11 = var12[var12.length - 1];
                  if (var6 == 0) {
                     if (var10 > 0 && (!var3 || var3 && this.checkInRange(var10 + 1, var4))) {
                        this.columnTitles.addElement(var11);
                     }
                  } else if (var10 == 0) {
                     this.rowTitles.addElement(var11);
                  } else if (!var3 || var3 && this.checkInRange(var10 + 1, var4)) {
                     try {
                        Float var13 = new Float(var11);
                        var9.addElement(var13);
                     } catch (Exception var14) {
                        var9.addElement(new Float((double)0.0F));
                     }
                  }
               }

               if (var6 > 0) {
                  this.data.addElement(var9);
               }
            }
         }
      }

      this.recalculateData();
   }

   protected void recalculateData() {
      this.biggestElement = 0.0F;
      this.smallestElement = 0.0F;

      for(int var1 = 0; var1 < this.data.size(); ++var1) {
         Vector var2 = this.getRecordValue((Vector)this.data.elementAt(var1));

         for(int var3 = 0; var3 < var2.size(); ++var3) {
            float var4 = (Float)var2.elementAt(var3);
            this.biggestElement = Math.max(this.biggestElement, var4);
            this.smallestElement = Math.min(this.smallestElement, var4);
         }
      }

      try {
         ChartRange.MinMax(this.numaxisLook, this.smallestElement, this.biggestElement, false);
      } catch (Exception var7) {
      }

      this.numaxisLook.labels = new String[this.numaxisLook.nMajorHash + 2];
      double var8 = this.numaxisLook.fMin;

      for(int var9 = 0; var9 < this.numaxisLook.labels.length; var8 += (double)this.numaxisLook.fDivSize) {
         this.numaxisLook.labels[var9] = (new Float(var8)).toString();
         ++var9;
      }

      this.ordaxisLook.labels = new String[this.rowTitles.size()];

      for(int var5 = 0; var5 < this.rowTitles.size(); ++var5) {
         this.ordaxisLook.labels[var5] = (String)this.rowTitles.elementAt(var5);
      }

      this.numCategories = this.rowTitles.size();
      this.numDataSets = this.columnTitles.size();

      try {
         this.legend.setData(this.columnTitles);
      } catch (Exception var6) {
      }

      this.recalculate(((Component)this).size().width, ((Component)this).size().height);
   }

   protected Vector getRecordValue(Vector var1) {
      if (!this.isStacked) {
         return var1;
      } else {
         float var2 = 0.0F;
         float var3 = 0.0F;

         for(int var4 = 0; var4 < var1.size(); ++var4) {
            float var5 = (Float)var1.elementAt(var4);
            if ((double)var5 < (double)0.0F) {
               var2 += var5;
            } else {
               var3 += var5;
            }
         }

         Vector var6 = new Vector();
         var6.addElement(new Float(var2));
         var6.addElement(new Float(var3));
         return var6;
      }
   }

   protected boolean checkInRange(int var1, Vector var2) {
      for(int var3 = 0; var3 < var2.size(); ++var3) {
         if (((RangeElement)var2.elementAt(var3)).check(var1)) {
            return true;
         }
      }

      return false;
   }

   protected String[] checkForTags(String var1) {
      String var2 = null;
      String var3 = null;
      String var4 = null;
      if (var1.indexOf("<") == 0 || var1.indexOf("\u0011") == 0) {
         int var5 = var1.indexOf(">") != -1 ? var1.indexOf(">") : var1.indexOf("\u0013");
         boolean var6 = false;

         while(var5 != -1) {
            if (var5 != -1) {
               String var7 = var1.substring(1, var5);
               StringTokenizer var8;
               if (var7.toUpperCase().startsWith("IMG")) {
                  var8 = new StringTokenizer(var7, " ");
               } else {
                  var8 = new StringTokenizer(var7, "=");
               }

               while(var8.hasMoreTokens()) {
                  String var9 = var8.nextToken();
                  if (var9.equalsIgnoreCase("IMG")) {
                     var9 = var8.nextToken();
                     if (var9.startsWith("SRC=")) {
                        var2 = var9.substring(4);
                     } else {
                        var2 = var9;
                     }
                  } else if (var9.equalsIgnoreCase("BGCOLOR")) {
                     var9 = var8.nextToken();
                     var3 = var9;
                  } else if (var9.equalsIgnoreCase("COLOR")) {
                     var9 = var8.nextToken();
                     var4 = var9;
                  } else {
                     var6 = true;
                  }
               }

               if (var6) {
                  break;
               }

               var1 = var1.substring(var5 + 1);
               var5 = var1.indexOf(">") != -1 ? var1.indexOf(">") : var1.indexOf("\u0013");
            }
         }
      }

      String[] var10 = new String[]{var2, var3, var4, var1};
      return var10;
   }

   protected boolean isVertical() {
      return true;
   }

   protected boolean isGrid() {
      return this.gridYes;
   }

   public void setStacked(boolean var1) {
      this.isStacked = var1;
      this.recalculateData();
      ((Component)this).repaint();
   }

   protected boolean isStackable() {
      return false;
   }

   protected boolean axisAreVisible() {
      return true;
   }

   protected void setBkColor(Color var1) {
      this.bkColor = var1;
   }

   public Dimension minimumSize() {
      return new Dimension(170, 170);
   }

   public void setAttribute(String var1, Object var2) {
      this.attributes.put(var1, var2);
      this.hasShadow = (Boolean)this.getAttribute(HARes.HC_ATTR_SHADOW);
      this.gridYes = (Boolean)this.getAttribute(HARes.HC_ATTR_GRID);
      boolean var3 = (Boolean)this.getAttribute(HARes.HC_ATTR_STACKED);
      if (var3 != this.isStacked) {
         this.setStacked(var3);
      }

      this.showValues = (Boolean)this.getAttribute(HARes.HC_ATTR_VALUES);
      Color var4 = (Color)this.getAttribute(HARes.HC_ATTR_BACKGROUND);
      if (var4 != this.bkColor) {
         this.setBkColor(var4);
      }

   }

   public boolean hasAttribute(String var1) {
      return this.attributes.containsKey(var1);
   }

   public Object getAttribute(String var1) {
      return this.attributes.get(var1);
   }
}
