package corel.webdata;

import java.awt.Canvas;
import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Insets;
import java.awt.Rectangle;
import java.util.Vector;

public class ChartLegend extends Canvas {
   protected ChartGeneric chart;
   protected Insets legendInsets = new Insets(7, 7, 7, 7);
   protected Insets textInsets = new Insets(3, 6, 3, 3);
   protected Vector datasetsTitles;

   public void paint(Graphics var1) {
      Dimension var2 = ((Component)this).size();
      GraphExt.draw3dRectEx(var1, 0, 0, var2.width, var2.height, 3);
      FontMetrics var3 = var1.getFontMetrics();

      try {
         int var4 = this.calcTextHeight(var3);
         Rectangle var5 = this.calcColorRect(var3);

         for(int var6 = 0; var6 < this.datasetsTitles.size(); ++var6) {
            if (this.chart != null) {
               try {
                  this.chart.paintLegendBox(var6, var1, new Rectangle(this.legendInsets.left, this.legendInsets.top + var6 * var4 + (var4 - var5.height) / 2, var5.width, var5.height), ColorMgr.chartColors[var6 % ColorMgr.chartColors.length]);
               } catch (Exception var7) {
               }
            } else {
               var1.drawRect(this.legendInsets.left, this.legendInsets.top + var6 * var4 + (var4 - var5.height) / 2, var5.width, var5.height);
               var1.setColor(ColorMgr.chartColors[var6 % ColorMgr.chartColors.length]);
               var1.fillRect(this.legendInsets.left + 1, this.legendInsets.top + var6 * var4 + (var4 - var5.height) / 2 + 1, var5.width - 1, var5.height - 1);
            }

            var1.setColor(Color.black);
            var1.drawString((String)this.datasetsTitles.elementAt(var6), this.legendInsets.left + var5.width + this.textInsets.left, this.legendInsets.top + this.textInsets.top + var6 * var4 + var3.getAscent());
         }

      } catch (Exception var8) {
      }
   }

   protected int calcTextHeight(FontMetrics var1) {
      return var1.getHeight() - var1.getLeading() + this.textInsets.top + this.textInsets.bottom;
   }

   protected int calcHeight(FontMetrics var1) {
      return this.calcTextHeight(var1) * this.datasetsTitles.size() + this.legendInsets.top + this.legendInsets.bottom;
   }

   protected int calcTextWidth(FontMetrics var1) {
      int var2 = 0;

      for(int var3 = 0; var3 < this.datasetsTitles.size(); ++var3) {
         var2 = Math.max(var2, var1.stringWidth((String)this.datasetsTitles.elementAt(var3)));
      }

      return var2 + this.textInsets.left + this.textInsets.right;
   }

   protected Rectangle calcColorRect(FontMetrics var1) {
      int var2 = var1.getHeight() - var1.getLeading();
      return new Rectangle(0, 0, (int)((double)var2 * (double)0.75F), (int)((double)var2 * (double)0.75F));
   }

   protected int calcWidth(FontMetrics var1) {
      return this.calcTextWidth(var1) + this.calcColorRect(var1).width + this.legendInsets.left + this.legendInsets.right;
   }

   public Dimension minimumSize() {
      FontMetrics var1 = ((Component)this).getGraphics().getFontMetrics();

      try {
         return new Dimension(this.calcWidth(var1), this.calcHeight(var1));
      } catch (Exception var2) {
         return new Dimension(70, 70);
      }
   }

   public Dimension preferredSize() {
      return this.minimumSize();
   }

   public void setData(Vector var1) {
      this.datasetsTitles = var1;
   }

   public void setChart(Object var1) {
      this.chart = (ChartGeneric)var1;
   }
}
