package corel.webdata;

import java.awt.Color;
import java.awt.Component;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Point;
import java.awt.Polygon;
import java.awt.Rectangle;
import java.util.Vector;

public class ChartLine extends ChartGeneric {
   protected static final int MARKSIZE = 4;
   protected boolean hasMarks;
   Point[][] points;

   public ChartLine(boolean var1, ChartLegend var2, boolean var3, String var4, boolean var5, Color var6, boolean var7) {
      super(var1, var2, var3, var4, var5, var6);
      this.hasMarks = var7;
      super.attributes.put(HARes.HC_ATTR_MARKS, new Boolean(this.hasMarks));
   }

   protected void recalculate(int var1, int var2) {
      super.recalculate(var1, var2);
      ((Component)this).getGraphics().getFontMetrics();
      int var3 = super.numaxisLook.pt2.y - super.numaxisLook.pt1.y;
      this.points = new Point[super.numCategories][super.numDataSets];

      for(int var4 = 0; var4 < super.numCategories; ++var4) {
         Vector var5 = (Vector)super.data.elementAt(var4);

         for(int var6 = 0; var6 < super.numDataSets; ++var6) {
            float var7 = (Float)var5.elementAt(var6);
            int var8 = (int)(var7 / ((float)(super.numaxisLook.nMajorHash + 1) * super.numaxisLook.fDivSize) * (float)var3);
            int var9 = super.numaxisLook.pt1.x + (super.ordaxisLook.divisions[var4 + 1] - super.ordaxisLook.divisions[var4]) / 2 + super.ordaxisLook.divisions[var4];
            int var10 = super.ordaxisLook.pt1.y - var8;
            this.points[var4][var6] = new Point(var9, var10);
         }
      }

   }

   protected void paintData(Graphics var1) {
      FontMetrics var2 = var1.getFontMetrics();

      for(int var3 = 0; var3 < this.points.length; ++var3) {
         for(int var4 = 0; var4 < this.points[var3].length; ++var4) {
            try {
               var1.setColor(ColorMgr.chartColors[var4 % ColorMgr.chartColors.length]);
               if (this.hasMarks) {
                  this.drawMark(var4, var1, this.points[var3][var4].x, this.points[var3][var4].y);
               }

               var1.drawLine(this.points[var3][var4].x, this.points[var3][var4].y, this.points[var3 + 1][var4].x, this.points[var3 + 1][var4].y);
            } catch (Exception var13) {
            }
         }
      }

      var1.setColor(Color.black);
      Rectangle var14 = new Rectangle();

      for(int var5 = 0; super.showValues && var5 < this.points.length; ++var5) {
         Vector var6 = (Vector)super.data.elementAt(var5);

         for(int var7 = 0; var7 < this.points[var5].length; ++var7) {
            float var8 = (Float)var6.elementAt(var7);
            String var9 = Float.toString(var8);
            Rectangle var10 = new Rectangle();
            int var11 = this.points[var5][var7].x;
            int var12 = this.points[var5][var7].y;
            var10.reshape(var11, var12, var2.stringWidth(var9), var2.getHeight());
            if (!var14.intersects(var10)) {
               ((ChartGeneric)this).drawStringByLine(var1, var11, var12, 4, var9, 0);
               var14 = var10;
            }
         }
      }

   }

   protected void drawMark(int var1, Graphics var2, int var3, int var4) {
      switch (var1 % 4) {
         case 0:
            Polygon var6 = new Polygon();
            var6.addPoint(var3, var4 - 4);
            var6.addPoint(var3 - 4, var4);
            var6.addPoint(var3, var4 + 4);
            var6.addPoint(var3 + 4, var4);
            var6.addPoint(var3, var4 - 4);
            var2.fillPolygon(var6);
            return;
         case 1:
            var2.fillRect(var3 - 4, var4 - 4 + 1, 8, 8);
            return;
         case 2:
            Polygon var5 = new Polygon();
            var5.addPoint(var3, var4 - 4);
            var5.addPoint(var3 - 4, var4 + 4);
            var5.addPoint(var3 + 4, var4 + 4);
            var5.addPoint(var3, var4 - 4);
            var2.fillPolygon(var5);
            return;
         case 3:
            var2.fillOval(var3 - 4 + 1, var4 - 4 + 1, 6, 6);
            return;
         default:
      }
   }

   public void paintLegendBox(int var1, Graphics var2, Rectangle var3, Color var4) {
      var2.setColor(var4);
      var2.drawLine(var3.x, var3.y + var3.height / 2, var3.x + var3.width, var3.y + var3.height / 2);
      if (this.hasMarks) {
         this.drawMark(var1, var2, var3.x + var3.width / 2 + 1, var3.y + var3.height / 2);
      }

   }

   public void setAttribute(String var1, Object var2) {
      super.setAttribute(var1, var2);
      this.hasMarks = (Boolean)((ChartGeneric)this).getAttribute(HARes.HC_ATTR_MARKS);
      if (var1.equals(HARes.HC_ATTR_MARKS)) {
         super.legend.repaint();
      }

   }

   public boolean hasAttribute(String var1) {
      return !var1.equals(HARes.HC_ATTR_STACKED) && !var1.equals(HARes.HC_ATTR_SHADOW) ? super.hasAttribute(var1) : false;
   }
}
