package corel.webdata;

import java.applet.Applet;
import java.awt.Checkbox;
import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Event;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.Label;
import java.util.Hashtable;
import java.util.Vector;

public class Chart extends Applet implements AnalyzerControl {
   protected String myName;
   protected int flowOrder;
   protected static final int BARCHART = 0;
   protected static final int COLUMNCHART = 1;
   protected static final int LINECHART = 2;
   protected static final int PIECHART = 3;
   protected static final int XYCHART = 4;
   protected static Hashtable typesTable = new Hashtable();
   protected static Hashtable typesIDsTable;
   protected static final Color DEFAULT_BK_COLOR;
   protected int type;
   protected int dataSeries;
   protected boolean legend;
   protected String title;
   protected String categoryTitle;
   protected String valueTitle;
   protected boolean grid;
   protected boolean printValues;
   protected boolean stacked;
   protected String bkImage;
   protected Color bkColor;
   protected boolean showPercent;
   protected boolean showValue;
   protected boolean separate;
   protected boolean separateBiggest;
   protected int separationFactor;
   protected boolean hasShadow;
   protected boolean hasMarks;
   protected boolean rowRange;
   protected boolean columnRange;
   protected Vector rangeElements;
   protected String data;
   protected Applet myApplet;
   Label titleLabel;
   Label categoryLabel;
   Label valueLabel;
   ChartLegend legendWindow;
   ChartGeneric chart;

   public Chart() {
      this(1, 0, false, (String)null, (String)null, (String)null, false, false, (String)null, DEFAULT_BK_COLOR, (String)null);
   }

   public Chart(Applet var1) {
      this.myApplet = var1;
   }

   public Chart(Applet var1, String var2) {
      this(var1);
      this.data = var2;
   }

   public Chart(int var1, int var2, boolean var3, String var4, String var5, String var6, boolean var7, boolean var8, String var9, Color var10, String var11) {
      this.type = var1;
      this.dataSeries = var2;
      this.legend = var3;
      this.title = var4;
      this.categoryTitle = var5;
      this.valueTitle = var6;
      this.grid = var7;
      this.printValues = var8;
      this.bkImage = var9;
      this.bkColor = var10;
      this.data = var11;
   }

   public void translateAttributes(Hashtable var1) {
      this.myName = AttrConverter.getStr(var1, HARes.HF_ATTR_NAME);
      this.flowOrder = AttrConverter.getInt(var1, HARes.HF_ATTR_FLOWORDER);
      String var2 = AttrConverter.getStr(var1, HARes.HC_ATTR_TYPE);

      try {
         this.type = (Integer)typesTable.get(var2);
      } catch (Exception var4) {
         this.type = 1;
      }

      this.legend = AttrConverter.getBool(var1, HARes.HC_ATTR_LEGEND);
      this.title = AttrConverter.getStr(var1, HARes.HC_ATTR_TITLE);
      this.categoryTitle = AttrConverter.getStr(var1, HARes.HC_ATTR_CATEGORYTITLE);
      this.valueTitle = AttrConverter.getStr(var1, HARes.HC_ATTR_VALUETITLE);
      this.grid = AttrConverter.getBool(var1, HARes.HC_ATTR_GRID);
      this.printValues = AttrConverter.getBool(var1, HARes.HC_ATTR_VALUES);
      this.bkImage = AttrConverter.getStr(var1, HARes.HC_ATTR_SRC);
      this.stacked = AttrConverter.getBool(var1, HARes.HC_ATTR_STACKED);
      this.showPercent = AttrConverter.getBool(var1, HARes.HC_ATTR_SHOWPERCENT);
      this.showValue = AttrConverter.getBool(var1, HARes.HC_ATTR_SHOWVALUE);
      this.separate = AttrConverter.getBool(var1, HARes.HC_ATTR_SEPARATE);
      this.separateBiggest = AttrConverter.getBool(var1, HARes.HC_ATTR_SEPARATEBIGGEST);
      this.separationFactor = AttrConverter.getInt(var1, HARes.HC_ATTR_SEPARATIONFACTOR);
      if (this.separationFactor == 0) {
         this.separationFactor = 5;
      }

      this.hasShadow = AttrConverter.getBool(var1, HARes.HC_ATTR_SHADOW);
      if (var1.contains(HARes.HC_ATTR_MARKS)) {
         this.hasMarks = AttrConverter.getBool(var1, HARes.HC_ATTR_MARKS);
      } else {
         this.hasMarks = true;
      }

      var2 = AttrConverter.getStr(var1, HARes.HC_ATTR_BACKGROUND);

      try {
         this.bkColor = new Color(Integer.valueOf(var2, 16));
      } catch (Exception var3) {
         this.bkColor = DEFAULT_BK_COLOR;
      }

      this.initializeLayout();
      this.setValue(this.data);
   }

   public void initializeLayout() {
      GridBagLayout var1 = new GridBagLayout();
      GridBagConstraints var2 = new GridBagConstraints();
      var2.insets = new Insets(5, 5, 5, 5);
      ((Container)this).setLayout(var1);
      this.titleLabel = new Label(this.title);
      this.categoryLabel = new Label(this.categoryTitle);
      this.valueLabel = new Label(this.valueTitle);
      this.legendWindow = new ChartLegend();
      this.chart = this.createChart(this.type);
      this.chart.setBkColor(this.bkColor);
      var2.gridx = 1;
      var2.gridy = 0;
      var1.setConstraints(this.titleLabel, var2);
      ((Container)this).add(this.titleLabel);
      if (this.chart.axisAreVisible()) {
         var2.gridx = this.chart.isVertical() ? 0 : 1;
         var2.gridy = this.chart.isVertical() ? 1 : 2;
         var1.setConstraints(this.valueLabel, var2);
         ((Container)this).add(this.valueLabel);
      }

      var2.gridx = 1;
      var2.gridy = 1;
      var2.weightx = (double)1.0F;
      var2.weighty = (double)1.0F;
      var2.fill = 1;
      var1.setConstraints(this.chart, var2);
      ((Container)this).add(this.chart);
      var2.weightx = (double)0.0F;
      var2.weighty = (double)0.0F;
      var2.fill = 0;
      if (this.chart.axisAreVisible()) {
         var2.gridx = this.chart.isVertical() ? 1 : 0;
         var2.gridy = this.chart.isVertical() ? 2 : 1;
         var1.setConstraints(this.categoryLabel, var2);
         ((Container)this).add(this.categoryLabel);
      }

      if (this.legend) {
         var2.gridx = 2;
         var2.gridy = 1;
         var1.setConstraints(this.legendWindow, var2);
         ((Container)this).add(this.legendWindow);
      }

   }

   protected void setChartType(String var1) {
      if (typesTable.containsKey(var1)) {
         int var2 = (Integer)typesTable.get(var1);
         if (var2 == this.type) {
            return;
         }

         this.type = var2;
         ChartGeneric var3 = this.chart;
         this.chart = this.createChart(var2);
         this.setValue(this.data, this.rowRange, this.columnRange, this.rangeElements);
         GridBagConstraints var4 = ((GridBagLayout)((Container)this).getLayout()).getConstraints(var3);
         ((GridBagLayout)((Container)this).getLayout()).setConstraints(this.chart, var4);
         ((Container)this).add(this.chart);
         ((Container)this).remove(var3);
         if (this.chart.axisAreVisible()) {
            var4 = new GridBagConstraints();
            var4.gridx = this.chart.isVertical() ? 1 : 0;
            var4.gridy = this.chart.isVertical() ? 2 : 1;
            ((GridBagLayout)((Container)this).getLayout()).setConstraints(this.categoryLabel, var4);
            ((Container)this).add(this.categoryLabel);
            var4.gridx = this.chart.isVertical() ? 0 : 1;
            var4.gridy = this.chart.isVertical() ? 1 : 2;
            ((GridBagLayout)((Container)this).getLayout()).setConstraints(this.valueLabel, var4);
            ((Container)this).add(this.valueLabel);
         } else {
            ((Container)this).remove(this.categoryLabel);
            ((Container)this).remove(this.valueLabel);
         }

         ((Container)this).layout();
         this.chart.repaint();
         this.legendWindow.repaint();
      }

   }

   public boolean action(Event var1, Object var2) {
      if (var2 instanceof String) {
         String var3 = (String)var2;
         if (typesTable.containsKey(var3)) {
            this.setAttribute(HARes.HC_ATTR_TYPE, var3);
         } else {
            boolean var4 = false;

            try {
               Checkbox var5 = (Checkbox)var1.target;
               var4 = var5.getState();
            } catch (Exception var6) {
            }

            this.setAttribute(var3, new Boolean(var4));
         }
      }

      return super.action(var1, var2);
   }

   public boolean hasAttribute(String var1) {
      if (var1.equals(HARes.HC_ATTR_TYPE)) {
         return true;
      } else {
         return var1.equals(HARes.HC_ATTR_LEGEND) ? true : this.chart.hasAttribute(var1);
      }
   }

   public Object getAttribute(String var1) {
      if (var1.equals(HARes.HC_ATTR_TYPE)) {
         return typesIDsTable.get(new Integer(this.type));
      } else {
         return var1.equals(HARes.HC_ATTR_LEGEND) ? new Boolean(this.legend) : this.chart.getAttribute(var1);
      }
   }

   public void setAttribute(String var1, Object var2) {
      if (this.chart.hasAttribute(var1)) {
         this.chart.setAttribute(var1, var2);
         this.chart.repaint();
      } else if (var1.equals(HARes.HC_ATTR_LEGEND)) {
         this.legend = (Boolean)var2;
         if (this.legend) {
            GridBagConstraints var3 = new GridBagConstraints();
            var3.gridx = 2;
            var3.gridy = 1;
            ((GridBagLayout)((Container)this).getLayout()).setConstraints(this.legendWindow, var3);
            ((Container)this).add(this.legendWindow);
         } else {
            ((Container)this).remove(this.legendWindow);
         }

         ((Container)this).layout();
         this.chart.repaint();
      } else if (var1.equals(HARes.HC_ATTR_TYPE)) {
         this.setChartType((String)var2);
      }

      if (this.hasAttribute(HARes.HC_ATTR_LEGEND)) {
         this.legend = (Boolean)this.getAttribute(HARes.HC_ATTR_LEGEND);
      }

      if (this.hasAttribute(HARes.HC_ATTR_GRID)) {
         this.grid = (Boolean)this.getAttribute(HARes.HC_ATTR_GRID);
      }

      if (this.hasAttribute(HARes.HC_ATTR_VALUES)) {
         this.printValues = (Boolean)this.getAttribute(HARes.HC_ATTR_VALUES);
      }

      if (this.hasAttribute(HARes.HC_ATTR_STACKED)) {
         this.stacked = (Boolean)this.getAttribute(HARes.HC_ATTR_STACKED);
      }

      if (this.hasAttribute(HARes.HC_ATTR_SHOWPERCENT)) {
         this.showPercent = (Boolean)this.getAttribute(HARes.HC_ATTR_SHOWPERCENT);
      }

      if (this.hasAttribute(HARes.HC_ATTR_SHOWVALUE)) {
         this.showValue = (Boolean)this.getAttribute(HARes.HC_ATTR_SHOWVALUE);
      }

      if (this.hasAttribute(HARes.HC_ATTR_SEPARATE)) {
         this.separate = (Boolean)this.getAttribute(HARes.HC_ATTR_SEPARATE);
      }

      if (this.hasAttribute(HARes.HC_ATTR_SEPARATEBIGGEST)) {
         this.separateBiggest = (Boolean)this.getAttribute(HARes.HC_ATTR_SEPARATEBIGGEST);
      }

      if (this.hasAttribute(HARes.HC_ATTR_SHADOW)) {
         this.hasShadow = (Boolean)this.getAttribute(HARes.HC_ATTR_SHADOW);
      }

      if (this.hasAttribute(HARes.HC_ATTR_MARKS)) {
         this.hasMarks = (Boolean)this.getAttribute(HARes.HC_ATTR_MARKS);
      }

   }

   protected ChartGeneric createChart(int var1) {
      switch (var1) {
         case 0:
            return new ChartBar(this.grid, this.legendWindow, this.printValues, this.bkImage, this.hasShadow, this.bkColor, this.stacked);
         case 1:
            return new ChartColumn(this.grid, this.legendWindow, this.printValues, this.bkImage, this.hasShadow, this.bkColor, this.stacked);
         case 2:
            return new ChartLine(this.grid, this.legendWindow, this.printValues, this.bkImage, this.hasShadow, this.bkColor, this.hasMarks);
         case 3:
         default:
            return new ChartPie(this.grid, this.legendWindow, this.printValues, this.bkImage, this.hasShadow, this.bkColor, this.showPercent, this.showValue, this.separate, this.separateBiggest, this.separationFactor);
      }
   }

   public void init() {
      this.getAppletParameters(this);
      this.initializeLayout();
      this.setValue(this.data);
   }

   public void start() {
   }

   public void run() {
   }

   public void stop() {
   }

   public void destroy() {
   }

   public void getAppletParameters(Applet var1) {
      String var2 = var1.getParameter(HARes.HA_PARAM_TYPE).toLowerCase();

      try {
         this.type = (Integer)typesTable.get(var2);
      } catch (Exception var8) {
         this.type = 1;
      }

      var2 = var1.getParameter(HARes.HA_PARAM_LEGEND);
      this.legend = var2 == null ? true : Boolean.valueOf(var2);
      var2 = var1.getParameter(HARes.HA_PARAM_SHADOW);
      this.hasShadow = var2 == null ? false : Boolean.valueOf(var2);
      var2 = var1.getParameter(HARes.HA_PARAM_STACKED);
      this.stacked = var2 == null ? false : Boolean.valueOf(var2);
      var2 = var1.getParameter(HARes.HA_PARAM_SHOWPERCENT);
      this.showPercent = var2 == null ? false : Boolean.valueOf(var2);
      var2 = var1.getParameter(HARes.HA_PARAM_SHOWVALUE);
      this.showValue = var2 == null ? false : Boolean.valueOf(var2);
      var2 = var1.getParameter(HARes.HA_PARAM_SEPARATE);
      this.separate = var2 == null ? false : Boolean.valueOf(var2);
      var2 = var1.getParameter(HARes.HA_PARAM_SEPARATEBIGGEST);
      this.separateBiggest = var2 == null ? false : Boolean.valueOf(var2);

      try {
         var2 = var1.getParameter(HARes.HA_PARAM_SEPARATIONFACTOR);
         this.separationFactor = Integer.valueOf(var2);
      } catch (Exception var7) {
         this.separationFactor = 5;
      }

      var2 = var1.getParameter(HARes.HA_PARAM_MARKS);
      this.hasMarks = var2 == null ? true : Boolean.valueOf(var2);
      this.title = var1.getParameter(HARes.HA_PARAM_TITLE);
      this.categoryTitle = var1.getParameter(HARes.HA_PARAM_CATEGORYTITLE);
      this.valueTitle = var1.getParameter(HARes.HA_PARAM_VALUETITLE);
      var2 = var1.getParameter(HARes.HA_PARAM_GRID);
      this.grid = var2 == null ? false : Boolean.valueOf(var2);
      var2 = var1.getParameter(HARes.HA_PARAM_PRINTVALUES);
      this.printValues = var2 == null ? false : Boolean.valueOf(var2);
      this.bkImage = var1.getParameter(HARes.HA_PARAM_SRC);
      var2 = var1.getParameter(HARes.HA_PARAM_BACKGROUND);

      try {
         this.bkColor = new Color(Integer.valueOf(var2, 16));
      } catch (Exception var6) {
         this.bkColor = DEFAULT_BK_COLOR;
      }

      int var3 = 0;

      try {
         var2 = var1.getParameter(HARes.HA_PARAM_NUMBEROFCOLUMNS);
         var3 = Integer.valueOf(var2);
      } catch (Exception var5) {
         var3 = 0;
      }

      for(int var4 = 0; var4 < var3; ++var4) {
         var2 = var1.getParameter(HARes.HA_PARAM_COL_ + var4);
         if (var2 == null || var2.length() == 0) {
            var2 = HARes.HA_DEF_COL_TITLE + var4;
         }

         String var10001 = this.data;
         this.data = var10001 + var2 + HARes.HA_FIELDDELIM;
         if (var4 == var3 - 1) {
            var10001 = this.data;
            this.data = var10001 + HARes.HA_RECORDDELIM;
         }
      }

      String var25 = this.data;
      this.data = var25 + AttrConverter.parseTextForAmpChars(var1.getParameter(HARes.HA_PARAM_DATA));
   }

   public void addAnalyzerControl(AnalyzerControl var1, String var2, Hashtable var3) {
   }

   public String getName() {
      return this.myName;
   }

   public String getValue() {
      return this.data;
   }

   public String getValue(String var1) {
      return this.getValue();
   }

   public boolean setValue(String var1) {
      return this.setValue(var1, false, false, (Vector)null);
   }

   public boolean setValue(String var1, boolean var2, boolean var3, Vector var4) {
      try {
         if (!var1.equals(this.data)) {
            this.data = var1;
         }

         this.rowRange = var2;
         this.columnRange = var3;
         this.rangeElements = var4;
         this.chart.setData(var1, this.rowRange, this.columnRange, this.rangeElements);
         ((Container)this).layout();
         this.chart.repaint();
         this.legendWindow.repaint();
      } catch (Exception var5) {
      }

      return false;
   }

   public boolean setValue(String var1, String var2) {
      return this.setValue(var1);
   }

   public boolean isValueValid() {
      return true;
   }

   public void reset(boolean var1) {
   }

   public boolean isContainer() {
      return false;
   }

   public boolean getValues(Hashtable var1) {
      return false;
   }

   public void setFocusOnMe(boolean var1) {
   }

   public void moveFocus(Component var1, boolean var2) {
   }

   public int getFlowOrder() {
      return this.flowOrder;
   }

   public int getNextFlowState() {
      return -1;
   }

   public void flowStateChanged(int var1, boolean var2, Component var3) {
   }

   public void enableControl(boolean var1) {
      ((Component)this).enable(var1);
   }

   static {
      typesTable.put(HARes.HC_TYPE_BAR.toLowerCase(), new Integer(0));
      typesTable.put(HARes.HC_TYPE_COLUMN.toLowerCase(), new Integer(1));
      typesTable.put(HARes.HC_TYPE_LINE.toLowerCase(), new Integer(2));
      typesTable.put(HARes.HC_TYPE_PIE.toLowerCase(), new Integer(3));
      typesIDsTable = new Hashtable();
      typesIDsTable.put(new Integer(0), HARes.HC_TYPE_BAR.toLowerCase());
      typesIDsTable.put(new Integer(1), HARes.HC_TYPE_COLUMN.toLowerCase());
      typesIDsTable.put(new Integer(2), HARes.HC_TYPE_LINE.toLowerCase());
      typesIDsTable.put(new Integer(3), HARes.HC_TYPE_PIE.toLowerCase());
      DEFAULT_BK_COLOR = Color.lightGray;
   }
}
