package corel.webdata;

import java.awt.Color;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.image.ImageObserver;
import java.util.Vector;

public class ViewField implements ImageObserver {
   public static final int DEFAULT_FIELD_HEIGHT = 20;
   protected final int DEFAULT_FIELD_WIDTH = 120;
   protected final int DEFAULT_FIELD_X_MARGIN = 3;
   protected final int DEFAULT_FIELD_Y_MARGIN = 2;
   protected String fieldText;
   protected String lineDelim;
   public static final int TYPE_STRING = 0;
   public static final int TYPE_LONG = 1;
   public static final int TYPE_IMAGE = 2;
   public static final int TYPE_MEMO = 3;
   public static final int TYPE_FLOAT = 4;
   protected int fieldType;
   protected Image myImage;
   protected Color fieldbgColor;
   protected Color fieldColor;
   protected boolean imageError = false;
   protected int fieldWidth = 120;
   protected int fieldHeight = 20;
   protected int imageHeight = 20;
   protected int imageWidth;
   protected Vector imArray;
   protected int imageIndex;
   protected boolean amISelected = false;

   public ViewField(String var1, Color var2, Color var3) {
      this.fieldText = var1;
      this.fieldType = 0;
      this.imageIndex = -1;
      this.fieldbgColor = var2;
      this.fieldColor = var3;
   }

   public ViewField(String var1, Vector var2, int var3, Color var4, Color var5) {
      this.fieldText = var1;
      this.fieldType = 0;
      this.imArray = var2;
      this.imageIndex = var3;
      this.getDimensions();
      this.fieldbgColor = var4;
      this.fieldColor = var5;
   }

   public ViewField(long var1, Color var3, Color var4) {
      this.fieldText = String.valueOf(var1);
      this.fieldType = 1;
      this.fieldbgColor = var3;
      this.fieldColor = var4;
   }

   public ViewField(long var1, Vector var3, int var4, Color var5, Color var6) {
      this.fieldText = String.valueOf(var1);
      this.fieldType = 1;
      this.imArray = var3;
      this.imageIndex = var4;
      this.getDimensions();
      this.fieldbgColor = var5;
      this.fieldColor = var6;
   }

   public ViewField(Vector var1, int var2, Color var3, Color var4) {
      this.fieldType = 2;
      this.imArray = var1;
      this.imageIndex = var2;
      this.getDimensions();
      this.myImage = (Image)this.imArray.elementAt(this.imageIndex);
      this.fieldbgColor = var3;
      this.fieldColor = var4;
   }

   public ViewField(String var1, String var2, Color var3, Color var4) {
      this.fieldType = 3;
      this.fieldText = var1;
      this.lineDelim = var2;
      this.fieldbgColor = var3;
      this.fieldColor = var4;
   }

   public ViewField(float var1, Color var2, Color var3) {
      this.fieldText = String.valueOf(var1);
      this.fieldType = 4;
      this.fieldbgColor = var2;
      this.fieldColor = var3;
   }

   public ViewField(float var1, Vector var2, int var3, Color var4, Color var5) {
      this.fieldText = String.valueOf(var1);
      this.fieldType = 4;
      this.imArray = var2;
      this.imageIndex = var3;
      this.getDimensions();
      this.fieldbgColor = var4;
      this.fieldColor = var5;
   }

   protected synchronized void getDimensions() {
      if (this.imageIndex == -1) {
         this.myImage = null;
      } else {
         this.myImage = (Image)this.imArray.elementAt(this.imageIndex);

         while((this.imageHeight = this.myImage.getHeight(this)) < 0) {
            try {
               this.wait();
            } catch (Exception var2) {
            }

            if (this.imageError) {
               this.myImage = null;
            }
         }

         while((this.imageWidth = this.myImage.getWidth(this)) < 0) {
            try {
               this.wait();
            } catch (Exception var1) {
            }

            if (this.imageError) {
               this.myImage = (Image)this.imArray.elementAt(this.imageIndex);
            }
         }

      }
   }

   public int getFieldHeight(Graphics var1) {
      if (this.fieldType == 2) {
         this.fieldHeight = this.imageHeight;
      }

      if (this.fieldType == 3) {
         this.fieldHeight = this.getMemoHeight(var1, this.fieldText);
      }

      if (this.fieldHeight < 20) {
         this.fieldHeight = 20;
      }

      return this.fieldHeight;
   }

   public int getFieldWidth(Graphics var1) {
      if (this.fieldType == 2) {
         this.fieldWidth = this.imageWidth;
      } else if (this.fieldType == 3) {
         this.fieldWidth = this.getMemoWidth(var1, this.fieldText);
      } else {
         FontMetrics var2 = var1.getFontMetrics();
         this.fieldWidth = var2.stringWidth(this.fieldText) + 6;
         if (this.myImage != null) {
            this.fieldWidth += this.imageWidth;
         }
      }

      if (this.fieldWidth < 40) {
         this.fieldWidth = 40;
      }

      return this.fieldWidth;
   }

   public String getText() {
      return this.fieldText;
   }

   public Color getbgColor() {
      return this.fieldbgColor;
   }

   public int getType() {
      return this.fieldType;
   }

   public boolean greaterThan(ViewField var1) {
      long var2;
      if (this.fieldType != var1.getType()) {
         var2 = -1L;
      } else {
         switch (this.fieldType) {
            case 0:
               var2 = (long)this.getText().compareTo(var1.getText());
               break;
            case 2:
               var2 = -1L;
               break;
            case 3:
               var2 = -1L;
            case 1:
               long var9 = new Long(this.getText());
               long var6 = new Long(var1.getText());
               var2 = var9 - var6;
               break;
            case 4:
               float var4 = new Float(this.getText());
               float var5 = new Float(var1.getText());
               if ((double)(var4 - var4) > (double)0.0F) {
                  var2 = 1L;
               } else if ((double)(var4 - var4) < (double)0.0F) {
                  var2 = -1L;
               } else {
                  var2 = 0L;
               }
               break;
            default:
               var2 = -1L;
         }
      }

      return var2 > 0L;
   }

   public synchronized void drawIt(Graphics var1, int var2, int var3, int var4, int var5) {
      switch (this.fieldType) {
         case 0:
         case 1:
         case 4:
            if (this.myImage != null) {
               while(!this.drawScaledImage(var1, this.myImage, 3, 2, this.getFieldHeight(var1) - 3, this.getFieldHeight(var1) - 2, this)) {
                  try {
                     this.wait();
                  } catch (InterruptedException var8) {
                  }
               }
            }

            String var6 = this.getCutText(var1, var4 - (this.myImage != null ? this.getFieldHeight(var1) : 0) - 3, this.getText());
            if (this.fieldColor == null) {
               var1.setColor(Color.black);
            } else {
               var1.setColor(this.fieldColor);
            }

            var1.drawString(var6, 3 + (this.myImage != null ? this.getFieldHeight(var1) : 0), this.getFieldTextPosY(var1, 2));
            return;
         case 2:
            if (this.myImage != null) {
               while(!var1.drawImage(this.myImage, 0, 0, this)) {
                  try {
                     this.wait();
                  } catch (InterruptedException var7) {
                  }
               }

               return;
            }
            break;
         case 3:
            this.drawMemoString(var1, var4, this.fieldText);
      }

   }

   protected boolean drawScaledImage(Graphics var1, Image var2, int var3, int var4, int var5, int var6, ImageObserver var7) {
      boolean var8;
      if (this.imageWidth <= var5 && this.imageHeight <= var6) {
         var8 = var1.drawImage(this.myImage, var3 + (var5 - this.imageWidth) / 2, var4 + (var6 - this.imageHeight) / 2, var7);
      } else {
         var8 = var1.drawImage(this.myImage, var3, var4, var5, var6, var7);
      }

      return var8;
   }

   protected String getCutText(Graphics var1, int var2, String var3) {
      String var5 = var3;
      FontMetrics var4 = var1.getFontMetrics();

      for(int var6 = 0; var4.stringWidth(var5) > var2; ++var6) {
         try {
            var5 = new String(var3.substring(0, var3.length() - var6) + "...");
         } catch (StringIndexOutOfBoundsException var7) {
         }
      }

      return var5;
   }

   protected int getFieldTextPosY(Graphics var1, int var2) {
      FontMetrics var3 = var1.getFontMetrics();
      int var4 = var2 + var3.getMaxAscent();
      return var4;
   }

   public synchronized boolean imageUpdate(Image var1, int var2, int var3, int var4, int var5, int var6) {
      if ((var2 & 64) != 0) {
         this.imageError = true;
      }

      this.notifyAll();
      return true;
   }

   protected void drawMemoString(Graphics var1, int var2, String var3) {
      int var4 = this.getFieldTextPosY(var1, 2);
      FontMetrics var5 = var1.getFontMetrics();

      for(ViewTokenizer var6 = new ViewTokenizer(var3, this.lineDelim); var6.hasMoreTokens(); var4 += var5.getHeight()) {
         String var7 = var6.getNextToken();
         String var8 = this.getCutText(var1, var2 - 3, var7);
         if (this.fieldColor == null) {
            var1.setColor(Color.black);
         } else {
            var1.setColor(this.fieldColor);
         }

         var1.drawString(var8, 3, var4);
      }

   }

   protected int getMemoHeight(Graphics var1, String var2) {
      FontMetrics var3 = var1.getFontMetrics();
      ViewTokenizer var4 = new ViewTokenizer(var2, this.lineDelim);
      return var4.countTokens() * var3.getHeight() + 4;
   }

   protected int getMemoWidth(Graphics var1, String var2) {
      FontMetrics var3 = var1.getFontMetrics();
      int var4 = 0;

      String var6;
      for(ViewTokenizer var5 = new ViewTokenizer(var2, this.lineDelim); var5.hasMoreTokens(); var4 = Math.max(var4, var3.stringWidth(var6))) {
         var6 = var5.getNextToken();
      }

      return var4 + 6;
   }

   public boolean isSortable() {
      return this.getType() != 2 && this.getType() != 3;
   }

   public void selectField() {
      this.amISelected = true;
   }

   public void unselectField() {
      this.amISelected = false;
   }

   public boolean isSelected() {
      return this.amISelected;
   }
}
